// ps4000wrap.cpp : Defines the entry point for the DLL application.
//
#include <windows.h>
#include <stdio.h>
#include "ps4000Api.h"

short _ready;
short _autoStop;
unsigned long _numSamples;
unsigned long _triggeredAt = 0;
short _triggered = FALSE;

void __stdcall StreamingCallback(
    short handle,
		long noOfSamples,
		unsigned long startIndex,
		short overflow,
		unsigned long triggerAt,
		short triggered,
		short autoStop,
		void * pParameter)
{
  _numSamples = noOfSamples;
  _autoStop = autoStop;

	_triggered = triggered;
	_triggeredAt = triggerAt;
  
  _ready = 1;
}

void __stdcall BlockCallback(short handle, PICO_STATUS status, void * pParameter)
{
  _ready = 1;
}

extern short __declspec(dllexport) __stdcall RunBlock(short handle, long preTriggerSamples, long postTriggerSamples, 
            unsigned long timebase, short oversample, short segmentIndex)
{
  _ready = 0;
  _numSamples = preTriggerSamples + postTriggerSamples;

  return (short) ps4000RunBlock(handle, preTriggerSamples, postTriggerSamples, timebase, oversample, 
    NULL, segmentIndex, BlockCallback, NULL);
}

extern short __declspec(dllexport) __stdcall GetStreamingLatestValues(short handle)
{
  _ready = 0;
  _numSamples = 0;
  _autoStop = 0;

  return (short) ps4000GetStreamingLatestValues(handle, StreamingCallback, NULL);
}

// TODO : all of the following functions take a handle but dont use them - should store a dictionary of handles vs results
extern unsigned long __declspec(dllexport) __stdcall AvailableData(short handle)
{
	if( _ready ) return _numSamples;
  return 0l;
}

extern short __declspec(dllexport) __stdcall AutoStopped(short handle)
{
  if( _ready) return _autoStop;
  return 0;
}

extern short __declspec(dllexport) __stdcall IsReady(short handle)
{
  return _ready;
}

extern short __declspec(dllexport) __stdcall IsTriggerReady(short handle, unsigned long *triggeredAt)
{
	if (_triggered)
		*triggeredAt = _triggeredAt;

  return _triggered;
}

extern short __declspec(dllexport) __stdcall ClearTriggerReady(void)
{
	_triggeredAt = 0;
	_triggered = FALSE;
	return 1;
}

extern short __declspec(dllexport) __stdcall SetTriggerConditions(short handle, int* conditionsArray, short nConditions)
{
	PICO_STATUS ok;
	short i = 0;
	TRIGGER_CONDITIONS *conditions = (TRIGGER_CONDITIONS *) calloc (nConditions, sizeof(TRIGGER_CONDITIONS));

	for (i = 0; i < nConditions; i++)
	{
		conditions[i].channelA = conditionsArray[0*(i+1)];
		conditions[i].channelB = conditionsArray[1*(i+1)];
		conditions[i].channelC = conditionsArray[2*(i+1)];
		conditions[i].channelD = conditionsArray[3*(i+1)];
		conditions[i].external = conditionsArray[4*(i+1)];
		conditions[i].pulseWidthQualifier = conditionsArray[5*(i+1)];
		conditions[i].aux = conditionsArray[6*(i+1)];
	}
	ok = ps4000SetTriggerChannelConditions(handle, conditions, nConditions);
	free (conditions);

	return ok;
}

extern short __declspec(dllexport) __stdcall SetTriggerProperties(
	short handle, 
	int *propertiesArray, 
	short nProperties, 
	short auxEnable, 
	long autoTrig)
{
	TRIGGER_CHANNEL_PROPERTIES *channelProperties = (TRIGGER_CHANNEL_PROPERTIES *) calloc(nProperties, sizeof(TRIGGER_CHANNEL_PROPERTIES));
	short i;
	short j=0;
	PICO_STATUS ok;
	
	for (i = 0; i < nProperties; i++)
	{
		channelProperties[i].thresholdUpper				= propertiesArray[j];
		channelProperties[i].thresholdUpperHysteresis	= propertiesArray[j+1];
		channelProperties[i].thresholdLower				= propertiesArray[j+2];
		channelProperties[i].thresholdLowerHysteresis	= propertiesArray[j+3];
		channelProperties[i].channel					= propertiesArray[j+4];
		channelProperties[i].thresholdMode				= propertiesArray[j+5];
		j=j+5;
	}
	ok = ps4000SetTriggerChannelProperties(handle, channelProperties, nProperties, auxEnable, autoTrig);
	free(channelProperties);
	return ok;
}